sin_theta_distance: Frobenius norm sin theta distance between two column spaces
Description
Frobenius norm sin theta distance between two column spaces
Usage
sin_theta_distance(V1, V2)
Arguments
V1
a matrix with orthonormal columns
V2
a matrix of the same dimension as V1 with orthonormal columns
Value
the Frobenius norm sin theta distance between two V1 and V2